/*global define,window*/
define([
    'testsuite/qunit',
    'jquery',
    'ep',
    'testsuite/qunit-fixture!./docdatapaystatus-test',
    'de_epages/docdatapay/ui/docdatapaystatus'
], function(QUnit, $, ep, fixture, docdatapaystatus) {

    'use strict';
    QUnit.module('de_epages/docdatapay/ui/docdatapaystatus', {
        setup: fixture.init,
        teardown: fixture.destroy
    });

//
    QUnit.test('Check if the behaviour of status link is as expected for non-ipayment payment methods ', 1, function() {

	        var UIControlParameters = {
	                Objectid: "12345",
	    		    PaymentTypeAlias: "SagePay",
	    		    TransStatus: "",
	    		    DisplayStatus: $('#DisplayStatus'),
	    		    StatusLink: $('#StatusLink')
	        };
	        
	        docdatapaystatus( UIControlParameters );

	        QUnit.strictEqual(
	            $("#DisplayStatus").is(":visible"),
	            false,
	            'Check that the div that contains the check status is not visible. We are waiting for the attribute visible of the above div at false'
	        );
	    });
    
//    
    QUnit.test('Check if the behaviour of status link is as expected for non-ipayment payment methods ', 1, function() {

	        var UIControlParameters = {
	                Objectid: "12345",
	    		    PaymentTypeAlias: "DocdataPay",
	    		    TransStatus: "",
	    		    DisplayStatus: $('#DisplayStatus'),
	    		    StatusLink: $('#StatusLink')
	        };
	        
	        docdatapaystatus( UIControlParameters );

	        QUnit.strictEqual(
	            $("#DisplayStatus").is(":visible"),
	            true,
	            'Check that the div that contains the check status is visible. We are waiting for the attribute visible of the above div at true'
	        );
	    });
    
//
    QUnit.test('Check if the behaviour of status link is as expected for transaction status = STATUS_PAID ', 1, function() {

        var UIControlParameters = {
                Objectid: "12345",
    		    PaymentTypeAlias: "DocdataPay",
    		    TransStatus: "STATUS_PAID",
    		    DisplayStatus: $('#DisplayStatus'),
    		    StatusLink: $('#StatusLink')
        };
        
        docdatapaystatus( UIControlParameters );

        QUnit.strictEqual(
            $("#StatusLink").attr('class'),
            'Disabled',
            'Check that the link has the expected classes for a properly execution. We are waiting for the values Disabled in link class attribute'
        );
    });
//       
	QUnit.test('Check if the behaviour of capture link is as expected for empty transaction status', 1, function() {

        var UIControlParameters = {
                Objectid: "12345",
    		    PaymentTypeAlias: "DocdataPay",
    		    TransStatus: "",
    		    DisplayStatus: $('#DisplayStatus'),
    		    StatusLink: $('#StatusLink')
        };
        
        docdatapaystatus( UIControlParameters );

        QUnit.strictEqual(
            $("#StatusLink").attr('class'),
            '',
            'Check that the link has the expected classes for a properly execution. We are waiting for the values  in link class attribute'
        );
    });

//
    QUnit.test('Check if the behaviour of status JSON message as expected if it goes well', 3, function() {

        ep.ajax = function(o) {
            var result = $.Deferred();

            result.resolve({
                "status": "ok",
                "message": "",
            });

            return result;
        };

        // Mocking the window to avoid the reload
        this.mockWindow = {
            location: {
                reload: function() {
                    ok(true, "This mock function should be called");
                }
            }
        };
        
        var UIControlParameters = {
                Objectid: "12345",
    		    PaymentTypeAlias: "DocdataPay",
    		    TransStatus: "",
    		    DisplayStatus: $('#DisplayStatus'),
    		    StatusLink: $('#StatusLink'),
    		    CurrentWindow: this.mockWindow
        };        

        docdatapaystatus( UIControlParameters );

        $('#StatusLink').trigger('click');
        $('#YesId').trigger('click');

        QUnit.strictEqual(
            $("#Response").html(),
            'OK',
            'Check that the value of the dialog is the expected for a properly execution. We are waiting for the word OK at the dialog'
        );
        
        QUnit.strictEqual(
	            $("#DocDataPayActionsNotificationDiv").is(":visible"),
	            false,
	            'Check that the div that contains the error message is not visible.'
	        );          
    });	
    
//
    QUnit.test('Check if the behaviour of status JSON message is as expected if it goes well', 2, function() {

        ep.ajax = function(o) {
            var result = $.Deferred();

            result.resolve({
                "status": "error",
                "message": "",
            });

            return result;
        };

        // Mocking the window to avoid the reload
        this.mockWindow = {
            location: {
                reload: function() {
                    ok(true, "This mock function should be called");
                }
            }
        };
        
        var UIControlParameters = {
                Objectid: "12345",
    		    PaymentTypeAlias: "DocdataPay",
    		    TransStatus: "",
    		    DisplayStatus: $('#DisplayStatus'),
    		    StatusLink: $('#StatusLink'),
    		    CurrentWindow: this.mockWindow
        };        

        docdatapaystatus( UIControlParameters );

        $('#StatusLink').trigger('click');
        $('#YesId').trigger('click');

        QUnit.strictEqual(
            $("#Response").html(),
            'ERROR',
            'Check that the value of the dialog is the expected for a properly execution. We are waiting for the word ERROR at the dialog'
        );
        
        QUnit.strictEqual(
	            $("#DocDataPayActionsNotificationDiv").is(":visible"),
	            true,
	            'Check that the div that contains the error message is visible.'
	        );                           
    });	

//
    QUnit.test('Check if the behaviour of status JSON message is as expected if it goes well', 2, function() {

        ep.ajax = function(o) {
            var result = $.Deferred();

            result.resolve({
                "status": "STATUS",
                "message": "",
            });

            return result;
        };

        // Mocking the window to avoid the reload
        this.mockWindow = {
            location: {
                reload: function() {
                    ok(true, "This mock function should be called");
                }
            }
        };
        
        var UIControlParameters = {
                Objectid: "12345",
    		    PaymentTypeAlias: "DocdataPay",
    		    TransStatus: "",
    		    DisplayStatus: $('#DisplayStatus'),
    		    StatusLink: $('#StatusLink'),
    		    CurrentWindow: this.mockWindow
        };        

        docdatapaystatus( UIControlParameters );

        $('#StatusLink').trigger('click');
        $('#YesId').trigger('click');

        QUnit.strictEqual(
            $("#Response").html(),
            'ERROR_DIF',
            'Check that the value of the dialog is the expected for a properly execution. We are waiting for the word ERROR_DIF at the dialog'
        );
        
        QUnit.strictEqual(
	            $("#DocDataPayActionsNotificationDiv").is(":visible"),
	            true,
	            'Check that the div that contains the error message is visible.'
	        );                    
    });	          
});